@@ -5,5 +5,4 @@ JAVAC = "javac"
 JAVA = "java"
 
 from . compile import compile, run
-from . junit5 import compile_test
-from . checks import is_application_class
+import checks
